@@ -312,6 +312,22 @@ where
             }
         max
     }
+    /// Shift subtree on x .
+    pub fn shift_x_subtree(&mut self,idx:usize, shift:f32)  {
+        let mut x = self.arena[idx].x;
+        x = x + shift;
+        info!("[shift_x_subtree] shifting node {} ({}) of {}",&self.arena[idx].name,&self.arena[idx].x,shift);
+        &self.arena[idx].set_x_noref(x);
+        info!("[shift_x_subtree] new value     {} ({})",&self.arena[idx].name,&self.arena[idx].x);
+        let children = &self.arena[idx].children;
+        if children.len() > 0 {
+        let left = children[0];
+        let right = children[1];
+        &self.shift_x_subtree(left, shift);
+        &self.shift_x_subtree(right, shift);
+        }
+
+    }
     /// Copy a whole ArenaTree structure.
     pub fn copie(&mut self) -> ArenaTree<String> {
         let  mut new: ArenaTree<String> = ArenaTree::default();
@@ -359,6 +375,8 @@ where
 ///  Structure Options: these are the drawing options for the svg. Concerning recPhyloXML file, we assume in the documentation that it describes a gene/species reconciliation.
 #[derive(Debug)]
 pub struct Options{
+    ///Display branch length
+    pub branch:bool,
     /// Display internal gene nodes.
     pub gene_internal: bool,
     /// Display internal species nodes (recPhyloXML).
@@ -391,6 +409,10 @@ pub struct Options{
     pub thickness_gene: usize,
     /// Display the abundance of the redundant transfers (recPhyloXML).
     pub thickness_disp_score:bool,
+    /// Tidy option
+    pub tidy:bool,
+    /// Tidy option
+    pub tidy_leaves_check:bool,
     /// Optimise species branches left/right orientation in order to minimise transfer crossings (recPhyloXML, under development).
     pub optimisation:bool,
     /// Scale to be applied to the heigth of the tree.
@@ -409,6 +431,7 @@ pub struct Options{
 impl Options {
     pub fn new() -> Self {
         Self {
+            branch:false,
             gene_internal:false,
             species_internal:false,
             clado_flag:true,
@@ -425,6 +448,8 @@ impl Options {
             thickness_thresh:0,
             thickness_gene:0,
             thickness_disp_score:false,
+            tidy:false,
+            tidy_leaves_check:false,
             optimisation:false,
             height:1.0,
             width:1.0,
@@ -1836,6 +1861,24 @@ pub fn  check_contour_postorder(tree: &mut ArenaTree<String>,index:usize) {
     else{
     }
 }
+
+
+/// Solve the conflicts between the left subtree and the right subtree.
+pub fn  check_contour_postorder_tidy_tree(tree: &mut ArenaTree<String>,index:usize,
+    options: &Options, config: &Config) {
+    info!("[check_contour_postorder_tidy_tree]");
+    info!("[check_contour_postorder_tidy_tree] node {}",tree.arena[index].name);
+    let children  = &mut  tree.arena[index].children;
+    if children.len() > 0 {
+        let left = children[0];
+        let right = children[1];
+        check_contour_postorder_tidy_tree(tree,right,options,config);
+        check_contour_postorder_tidy_tree(tree,left,options,config);
+        push_right_tidy_tree(tree,left,right,options,config);
+        set_middle_postorder(tree, 0);
+    }
+}
+
 /// Get the leftest  or rightest x value of a node.
 pub fn node_xpos(tree: &mut ArenaTree<String>, index: usize, xmod: f32, operator : i32) -> f32 {
     tree.arena[index].x + tree.arena[index].xmod
@@ -1898,6 +1941,57 @@ pub fn  get_contour_right(tree: &mut ArenaTree<String>,index:usize,depth:usize,
         get_contour_right(tree,right,depth,contour_right,tree.arena[index].xmod + parent_xmod );
     }
 }
+/// Get the right 'contour' of a sub tree in the "tidy" context.
+pub fn  get_contour_tidy_right(tree: &mut ArenaTree<String>,index:usize,depth:usize,
+    contour_right: &mut Vec<(f32,f32,String)>, ymax: &mut f32, options: &Options,config: &Config)  {
+    // let children  = &mut  tree.arena[index].children;
+    let x = tree.arena[index].x  + tree.arena[index].nbg as f32 *PIPEBLOCK /2.0;
+    let mut y = tree.arena[index].y  + tree.arena[index].nbg as f32 *PIPEBLOCK /2.0;
+    // avoid superposition of leaves
+    if tree.is_leaf(index) {
+        y = y + match options.tidy_leaves_check {
+            false => 5.0,
+            true => tree.arena[index].name.len() as f32 * config.gene_police_size.parse::<f32>().unwrap(),
+        };
+    }
+    let name  = &tree.arena[index].name;
+    if y >= *ymax {
+        contour_right.push((x,y,name.to_string()));
+        *ymax=y;
+    }
+    let children  = &mut  tree.arena[index].children;
+    if children.len() > 0 {
+        let right = children[1];
+        let left = children[0];
+        get_contour_tidy_right(tree,right,depth,contour_right,ymax,options,config);
+        get_contour_tidy_right(tree,left,depth,contour_right,ymax,options,config);
+    }
+}
+/// Get the left 'contour' of a sub tree in the "tidy" context.
+pub fn  get_contour_tidy_left(tree: &mut ArenaTree<String>,index:usize,depth:usize,
+    contour_left: &mut Vec<(f32,f32,String)>, ymax: &mut f32,options: &Options,config: &Config)  {
+    let x = tree.arena[index].x  - tree.arena[index].nbg as f32 *PIPEBLOCK /2.0 ;
+    let mut y = tree.arena[index].y + tree.arena[index].nbg as f32 *PIPEBLOCK /2.0;
+    // avoid superposition of leaves
+    if tree.is_leaf(index) {
+        y = y + match options.tidy_leaves_check {
+            false => 5.0,
+            true => tree.arena[index].name.len() as f32 *config.gene_police_size.parse::<f32>().unwrap(),
+        };
+    }
+    let name =  &tree.arena[index].name;
+    if y >= *ymax{
+        *ymax = y;
+        contour_left.push((x,y,name.to_string()));
+    }
+    let children  = &mut  tree.arena[index].children;
+    if children.len() > 0 {
+        let left = children[0];
+        let right = children[1];
+        get_contour_tidy_left(tree,left,depth,contour_left,ymax,options,config);
+        get_contour_tidy_left(tree,right,depth,contour_left,ymax,options,config);
+    }
+}
 /// Check for conficts between subtrees and shift conflicting right-hand subtrees to the right
 /// in order to solve detected conflicts.
 pub fn  push_right(tree: &mut ArenaTree<String>,left_tree:usize,right_tree:usize) -> f32 {
@@ -1953,6 +2047,61 @@ pub fn  push_right(tree: &mut ArenaTree<String>,left_tree:usize,right_tree:usize
     }
     0.0
 }
+/// Get the minimal distance between 2 contours in "tidy" context.
+pub fn  dmin_tidy(cont_left:Vec<(f32,f32,String)>,cont_right:Vec<(f32,f32,String)>, dmin:&mut f32, index_left:&mut usize,index_right:&mut usize)  {
+let max_left = cont_left.len();
+let max_right = cont_right.len();
+info!("[dmin_tidy] dmin {}",dmin);
+info!("[dmin_tidy] left  contour {}{:?}",index_left,cont_left);
+info!("[dmin_tidy] right contour {}{:?}",index_right,cont_right);
+info!("[dmin_tidy] Compare x value of  right {} and  left  {}",cont_left[*index_left].2,cont_right[*index_right].2,);
+let d = cont_right[*index_right].0 - cont_left[*index_left].0;
+if d < *dmin {
+    *dmin = d;
+    info!("[dmin_tidy] new dmin = {} ",dmin);
+    }
+info!("[dmin_tidy] Compare y value of  right {} {} and  left  {} {}",cont_left[*index_left].2,cont_left[*index_left].1,cont_right[*index_right].2,cont_right[*index_right].1);
+if cont_right[*index_right].1 <= cont_left[*index_left].1 {
+info!("[dmin_tidy] increment right");
+    *index_right = *index_right + 1;
+    if *index_right < max_right {
+        dmin_tidy(cont_left,cont_right,dmin,index_left,index_right);
+    }
+}
+else  {
+    info!("[dmin_tidy] increment left");
+    *index_left = *index_left + 1;
+    if *index_left < max_left {
+        dmin_tidy(cont_left,cont_right,dmin,index_left,index_right);
+    }
+}
+}
+/// Check for conficts between subtrees and shift conflicting right-hand subtrees to the right
+/// in order to solve detected conflicts in the "tidy" context.
+pub fn  push_right_tidy_tree(tree: &mut ArenaTree<String>,left_tree:usize,right_tree:usize,
+    options: &Options, config: &Config) {
+    info!("[push_right_tidy_tree]");
+    info!("[push_right_tidy_tree] Compare right contour of {} {} and left contour of {} {}",tree.arena[left_tree].val,tree.arena[left_tree].name,tree.arena[right_tree].val,tree.arena[right_tree].name );
+    let mut  right_co_of_left_tr:std::vec::Vec<(f32,f32,String)> = Vec::new();
+    let depth_left_tr  = tree.depth(left_tree);
+    get_contour_tidy_right(tree,left_tree,depth_left_tr,&mut right_co_of_left_tr,&mut 0.0,options,config);
+    info!("[push_right_tidy_tree] Contour right = {:?}",right_co_of_left_tr);
+    let mut  left_co_of_right_tr:std::vec::Vec<(f32,f32,String)> = Vec::new();
+    let depth_right_tr  = tree.depth(right_tree);
+    get_contour_tidy_left(tree,right_tree,depth_right_tr,&mut left_co_of_right_tr,&mut 0.0,options,config);
+    info!("[push_right_tidy_tree] Contour left = {:?}",left_co_of_right_tr);
+    let mut dmin = 1000000.0;
+    dmin_tidy(right_co_of_left_tr,left_co_of_right_tr,&mut dmin, &mut 0, &mut 0);
+    info!("[push_right_tidy_tree] DMIN = {:?} [max = {}]",dmin,PIPEBLOCK);
+    if dmin > BLOCK * 0.50 {
+        info!("[push_right_tidy_tree] SHIFTING SUBTREE  {:?} {:?}",tree.arena[left_tree].val,tree.arena[left_tree].name);
+        tree.shift_x_subtree(left_tree,dmin - BLOCK * 0.50  );
+        set_middle_postorder( tree, 0);
+    }
+    else {
+        info!("[push_right_tidy_tree] NOT SHIFTING ");
+    }
+}
 /// Set the x of the father between its children.
 pub fn  set_middle_postorder(tree: &mut ArenaTree<String>,index:usize) {
     let children  = &mut  tree.arena[index].children;
