@@ -59,12 +59,13 @@ pub fn draw_tree (
         false => Document::new()
                 .set("width",width_svg  )
                 .set("height",height_svg  )
-                .set("viewBox", (y_viewbox,x_viewbox,width_svg + 0.5 *BLOCK ,height_svg + 2.0 *BLOCK )),
+                .set("viewBox", (x_viewbox,y_viewbox,width_svg + 2.0 *BLOCK ,height_svg + 2.0 *BLOCK )),
     };
     let style = Style::new(".gene { font-size:  ".to_owned()
         + &config.gene_police_size.to_string()+"px; fill:"
         + &gene_color.to_string() + "; } .support { font-size: "
-        + &config.gene_police_size.to_string()+"px; fill: red; }" );
+        + &config.gene_police_size.to_string()+"px; fill: red; } .branch { font-size: "
+        + &config.gene_police_size.to_string()+"px; fill: black; }" );
     document.append(style);
     let mut g = Element::new("g");
     for  index in &tree.arena {
@@ -146,12 +147,40 @@ pub fn draw_tree (
                             false => {},
                         },
             };
+            // Display branch length
+            match options.branch {
+                true => {
+                    // only if  the node has a parent
+                    match index.parent {
+                        Some(p)=> {
+                            let mut element = Element::new("text");
+                            let n = &tree.arena[p];
+                            let x_dist = index.x +5.0;
+                            // Display in the furst quarter of the branch lenght
+                            let y_dist = n.y + (index.y - n.y)/4.0 ;
+                            element.assign("x", x_dist);
+                            element.assign("y", y_dist);
+                            element.assign("class", "branch");
+                            let txt  = Text::new(&index.l.to_string());
+                            element.append(txt);
+                            element.assign("transform","rotate(90 ".to_owned()+&(x_dist).to_string()
+                            + ","+&(y_dist).to_string()+")");
+                            g.append(element);
+                        },
+                        None => {},
+                    }
+                },
+                false => {},
+            }
         }
     }
+    // Note : simple tree
     let mut transfo: String = "translate(  ".to_owned();
+    // transfo.push_str(&( x_viewbox).to_string());
     transfo.push_str(&( x_viewbox).to_string());
     transfo.push_str(" ");
-    transfo.push_str(&((width_svg  + y_viewbox)).to_string());
+    let psize= &config.gene_police_size.parse::<f32>().unwrap();
+    transfo.push_str(&((width_svg  + y_viewbox + x_viewbox + psize)).to_string());
     transfo.push_str(") rotate(-90 0 0 ) ");
     match options.rotate {
         true => g.assign("transform",transfo),
@@ -231,7 +260,7 @@ pub fn draw_sptree_gntrees (
         false => Document::new()
                 .set("width",width_svg  )
                 .set("height",height_svg  )
-                .set("viewBox", (y_viewbox,x_viewbox,width_svg + 0.5 *BLOCK ,height_svg *1.1 + 2.0 *BLOCK )),
+                .set("viewBox", (x_viewbox,y_viewbox - 0.5 *BLOCK ,width_svg + 0.5 *BLOCK ,height_svg *1.1 + 0.5 *BLOCK )),
     };
     // Initialse la chaine de carctere dediee aux styles des fonts : font pour l'espece
     let mut recphylostyle:String = ".species { font: italic ".to_owned()
@@ -338,9 +367,37 @@ pub fn draw_sptree_gntrees (
                 };
             },
         };
+
+        // Display branch length
+        match options.branch {
+            true => {
+                // only if  the node has a parent
+                match index.parent {
+                    Some(p)=> {
+                        let mut element = Element::new("text");
+                        let n = &sp_tree.arena[p];
+                        let x_dist = index.x + index.width/2.0 + 5.0;
+                        // Display in the furst quarter of the branch lenght
+                        let y_dist = n.y + (index.y - n.y)/4.0  + index.height/2.0 ;
+                        element.assign("x", x_dist);
+                        element.assign("y", y_dist);
+                        element.assign("class", "branch");
+                        let txt  = Text::new(&index.l.to_string());
+                        element.append(txt);
+                        element.assign("transform","rotate(90 ".to_owned()+&(x_dist).to_string()
+                        + ","+&(y_dist).to_string()+")");
+                        g.append(element);
+                    },
+                    None => {},
+                }
+            },
+            false => {},
+        }
      }
+
     let  nb_gntree =  gene_trees.len(); // Nombre d'arbres de gene
     let mut idx_rcgen = 0;
+
      // Boucle sur les arbres de genes
     loop {
         let base_couleur = match &idx_rcgen % 6 {
@@ -551,6 +608,14 @@ pub fn draw_sptree_gntrees (
         let add_style_str :&str  =     &added_style;
         recphylostyle.push_str(add_style_str);
     }
+    if options.branch {
+        // Style de la font pour affichage du nb de transcr
+         let added_style = " .branch { font-size: ".to_owned()+ &config.species_police_size.to_string()
+            +"px; fill:black ; } ";
+        // Je passe en str pour l'ajouter
+        let add_style_str :&str  =     &added_style;
+        recphylostyle.push_str(add_style_str);
+    }
     // Ajout le style
     let style = Style::new(recphylostyle);
     document.append(style);
